@@ -46,7 +46,6 @@
 #define SYLPHEED_RC_DIR		".sylpheed-2.0"
 #define NEWS_CACHE_DIR		"newscache"
 #define IMAP_CACHE_DIR		"imapcache"
-#define MBOX_CACHE_DIR		"mboxcache"
 #define HEADER_CACHE_DIR        "headercache" 
 #define MIME_TMP_DIR		"mimetmp"
 #define COMMON_RC		"clawsrc"
@@ -133,9 +132,6 @@
 
 #define BUFFSIZE			8192
 
-/* according to RFC 821 1000 characters including CRLF */
-#define MAXSMTPTEXTLEN			1000
-
 #ifndef MAXPATHLEN
 #  define MAXPATHLEN			4095
 #endif
