@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
-typedef struct _SummaryView		SummaryView;
+#include "viewtypes.h"
 typedef struct _SummaryColumnState	SummaryColumnState;
 
 #define MAIL_MANUAL_FILTERING_HOOKLIST "mail_manual_filtering_hooklist"
@@ -61,20 +61,18 @@ typedef enum
 typedef enum
 {
 	TARGET_MAIL_URI_LIST,
-	TARGET_DUMMY
+	TARGET_DUMMY,
+	TARGET_MAIL_CM_PATH_LIST,
 } TargetInfo;
 
 #include "mainwindow.h"
-#include "folderview.h"
-#include "headerview.h"
-#include "messageview.h"
 #include "compose.h"
 #include "folder.h"
 #include "gtksctree.h"
 #include "prefs_filtering.h"
 #include "quicksearch.h"
 
-extern GtkTargetEntry summary_drag_types[2];
+extern GtkTargetEntry summary_drag_types[3];
 
 struct _SummaryColumnState
 {
@@ -114,7 +112,6 @@ struct _SummaryView
 
 	GtkCMCTreeNode *selected;
 	GtkCMCTreeNode *displayed;
-	GtkCMCTreeNode *last_displayed;
 
 	gboolean display_msg;
 
@@ -169,10 +166,12 @@ private:
 	gint folder_update_callback_id;
 
 	GtkTargetList *target_list; /* DnD */
-	
-#if !GTK_CHECK_VERSION(2,12,0)
-	GtkTooltips *tooltips;
-#endif
+
+	// folders with matches for recursive quicksearch queries
+	GSList *recursive_matched_folders;
+	FolderItem *search_root_folder;
+
+	guint mark_as_read_timeout_tag;
 };
 
 SummaryView	*summary_create(MainWindow *mainwin);
@@ -187,6 +186,7 @@ void summary_lock		  (SummaryView		*summaryview);
 void summary_unlock		  (SummaryView		*summaryview);
 void summary_freeze		  (SummaryView		*summaryview);
 void summary_thaw		  (SummaryView		*summaryview);
+void summary_thaw_with_status	  (SummaryView		*summaryview);
 void summary_grab_focus		  (SummaryView		*summaryview);
 GtkWidget *summary_get_main_widget(SummaryView 		*summaryview);
 gboolean summary_is_locked	  (SummaryView		*summaryview);
@@ -203,10 +203,12 @@ void summary_select_prev_marked	  (SummaryView		*summaryview);
 void summary_select_next_marked	  (SummaryView		*summaryview);
 void summary_select_prev_labeled  (SummaryView		*summaryview);
 void summary_select_next_labeled  (SummaryView		*summaryview);
-void summary_select_last_read     (SummaryView		*summaryview);
 void summary_select_parent        (SummaryView		*summaryview);
 void summary_select_by_msgnum	  (SummaryView		*summaryview,
 				   guint		 msgnum);
+void summary_display_by_msgnum	  (SummaryView		*summaryview,
+				   guint		 msgnum);
+void summary_select_by_msg_list   (SummaryView		*summaryview, GSList *msginfos);
 guint summary_get_current_msgnum  (SummaryView		*summaryview);
 void summary_select_node	  (SummaryView		*summaryview,
 				   GtkCMCTreeNode		*node,
@@ -287,7 +289,8 @@ void summary_add_address	  (SummaryView		*summaryview);
 void summary_select_all		  (SummaryView		*summaryview);
 void summary_unselect_all	  (SummaryView		*summaryview);
 void summary_select_thread	  (SummaryView		*summaryview,
-				   gboolean		 delete_thread);
+				   gboolean		 delete_thread,
+				   gboolean		 trash_thread);
 
 void summary_set_colorlabel	  (SummaryView		*summaryview,
 				   guint		 labelcolor,
@@ -300,6 +303,8 @@ void summary_set_column_order	  (SummaryView		*summaryview);
 
 void summary_toggle_show_read_messages
 				  (SummaryView *summaryview);
+void summary_toggle_show_read_threads
+				  (SummaryView *summaryview);
 void summary_toggle_show_del_messages
 				  (SummaryView *summaryview);
 
@@ -323,4 +328,5 @@ void summary_set_menu_sensitive	(SummaryView		*summaryview);
 void summary_relayout(SummaryView *summaryview);
 void summary_update_unread(SummaryView *summaryview, FolderItem *removed_item);
 gboolean summary_is_list(SummaryView *summaryview);
+gboolean summaryview_search_root_progress(gpointer data, guint at, guint matched, guint total);
 #endif /* __SUMMARY_H__ */
